require, "asciilib.i";
require, "graphlib.i";
require, "geolib.i";
require, "climber3a.i";
include, "ncops.i";


// Figure 3, left column, On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation
func devn_plot_veg( timeslice= )
{

  if( is_void(timeslice) )
    timeslice = "380Ma";


  // --------------------------------------------------------------------
  // READ TOPOGRAPHY INPUT DATA
  // --------------------------------------------------------------------

  // read topography data provided by Chris Scotese: the file format
  // changed at some point: for 415 Ma and 390 Ma the data are written
  // as (lat,lon,elev) whereas for the later times the format is
  // (lon,lat,elev)
  local lat1, lon1, elev1;
  if( timeslice=="415Ma" | timeslice=="390Ma" )
    read_columns, swrite( format="Data/%sPaleoDEMScotese.dat", timeslice ), 
      1,lat1, 2,lon1, 3,elev1;
  if( timeslice=="380Ma" | timeslice=="360Ma" )
    read_columns, swrite( format="Data/%sPaleoDEMScotese.dat", timeslice ), 
      1,lon1, 2,lat1, 3,elev1;


  // --------------------------------------------------------------------
  // CREATE ARRAYS
  // --------------------------------------------------------------------

  // the original data are on a 1-degree resolution:
  lat = span( -89.5, 89.5, 180 );
  lon = span( 0.5, 359.5, 360 );
  // NB: original data are from -180 to +180 in longitude, we just shift
  // the coordinate system by 180 degrees to facilitate interpolation
  // on model grid ranging from 0 to 360
  // 2D arrays of original grid (only used for Arctic test!):
  lat_2 = lat(-:1:numberof(lon),);
  lon_2 = lon(,-:1:numberof(lat));

  // create 2D array from input data file: the data are stored in one
  // column, but the file format changed at some point:
  // 415 Ma, 390 Ma: longitudes range from -179.5 to +179.5, latitudes
  // from +89.5 to -89.5; 
  elev = array( 0., 360, 180 );
  if( timeslice=="415Ma" | timeslice=="390Ma" )
    for( nlat=1; nlat<180; nlat++ )
      elev(,180-nlat+1) = elev1( ((nlat-1)*360+1):(nlat*360) );
  // 380 Ma, 360 Ma: longitudes range from -180 to +180, latitudes
  // from +90 to -90; all values for longitude -180 have value zero,
  // so we rearrange to an array with dimensions [360,180]:
  if( timeslice=="380Ma" | timeslice=="360Ma" )
    for( nlat=1; nlat<=180; nlat++ )
      elev(,180-nlat+1) = elev1( ((nlat-1)*361+2):(nlat*361) );

  // construct land-ocean mask:
  lom = ( elev>0. );

  // construct CLIMBER-3alpha atmosphere grid:
  lat_a = span( -86.25, +86.25, 24 );
  lon_a = span( 11.25, 348.75, 16 );
  // 2D arrays:
  lat_a2 = lat_a(-:1:numberof(lon_a),);
  lon_a2 = lon_a(,-:1:numberof(lat_a));

  // only for test plot: atmosphere grid corners:
  lat_ac = span( -90., 90., 25 );
  lon_ac = span( 0., 360., 17 );
  // 2D arrays:
  lat_ac2 = lat_ac(-:1:numberof(lon_ac),);
  lon_ac2 = lon_ac(,-:1:numberof(lat_ac));



  // --------------------------------------------------------------------
  // GENERATE VEGETATION DISTRIBUTIONS
  // --------------------------------------------------------------------

  // OK, for the assignment of vegetation for the Devonian we need a
  // measure for the minimum distance from the coast for each land
  // cell on the original grid; here is the definition of the original
  // grid from above:
  //  lat = span( -89.5, 89.5, 180 );
  //  lon = span( 0.5, 359.5, 360 );
  // 2D arrays:
  //  lat_2 = lat(-:1:numberof(lon),);
  //  lon_2 = lon(,-:1:numberof(lat));
  // these are in degrees, we need them in radians:
  lat_2r = lat_2/180.*pi;
  lon_2r = lon_2/180.*pi;
  // we have to do this for all land cells on the original grid:
  w = where( lom>0. ); // select land cells
  // set Earth radius (km):
  re = 6371.;
  // initialise minimum distance array:
  mind = lom;
  for( n=1; n<=numberof(w); n++ ){
    // compute 2D distance matrix:
    t = sin(lat_2r)*sin(lat_2r(w(n))) + 
      cos(lat_2r)*cos(lat_2r(w(n)))*cos(lon_2r-lon_2r(w(n)));
    // sometimes rounding errors cause the acos function to crash:
    ww = where( t>1. );
    if(numberof(ww))
      t(ww)=1.;
    ww = where( t<-1. );
    if(numberof(ww))
      t(ww)=-1.;
    dist2 = re * acos( t );
    
    mind(w(n)) = min(dist2(where(lom==0)));
  }


  // assign tree, grass and bare-land fractions on the CLIMBER-3alpha
  // atmosphere grid; this is the corrected version:
  fl_a = 0.*abs(lat_a2);
  //
  // CASE 1: we assume zero vegetation in this case, assignment
  // directly on the atmosphere grid:
  //
  ft1_a = fg1_a = fb1_a = 0.*abs(lat_a2);
  //
  // CASE 2: Early Devonian
  //     0km <= d < 300km,   0m <= e < 300m: 60% grass 
  //                                         (2/3 bryophytes, 1/3 shrubs)
  //            d < 500km, 300m <= e < 500m: 10% grass 
  //                                         (2/3 bryophytes, 1/3 shrubs)
  //   300km <  d < 500km,         e < 500m: 10% grass 
  //                                         (2/3 bryophytes, 1/3 shrubs)
  //   500km <= d,         500m <= e:        bare land
  //
  ft2_a = fg2_a = fb2_a = 0.*abs(lat_a2);
  fg2   = ft2   = elev*0.; fb2 = fg2 + 1.;
  w = where( lom>0. & elev<300. & mind<300. );
  fg2(w) = 0.6;
  ft2(w) = 0.0;
  w = where( lom>0. & elev>=300. & elev<500. & mind<500. );
  fg2(w) = 0.1;
  ft2(w) = 0.0;
  w = where( lom>0. & elev<500. & mind>=300. & mind<500. );
  fg2(w) = 0.1;
  ft2(w) = 0.0;
  //
  // CASE 3: Middle Devonian
  //     0km <= d < 500km,   0m <= e < 500m: 70% grass 
  //                                         (4/5 shrubs+1/5 bryophytes),
  //                                         10% trees (small trees/tall grass)
  //   500km <= d,         500m <= e:        bare land
  //
  ft3_a = fg3_a = fb3_a = 0.*abs(lat_a2);
  fg3   = ft3   = elev*0.; fb3 = fg3 + 1.;
  w = where( lom>0. & elev<500. & mind<500. );
  fg3(w) = 0.7;
  ft3(w) = 0.1;
  //
  // CASE 4: Late Devonian
  //      0km <= d <  500km,    0m <= e <  500m: 40% grass 
  //                                             (4/5 shrubs+1/5 bryophytes),
  //                                             40% trees
  //             d < 1000km,  500m <= e < 1000m: 30% grass 
  //                                             (4/5 shrubs+1/5 bryophytes),
  //                                             30% trees
  //    500km    d < 1000km,          e < 1000m: 30% grass 
  //                                             (4/5 shrubs+1/5 bryophytes),
  //                                             30% trees
  //   1000km <= d,          1000m <= e:         bare land
  //
  ft4_a = fg4_a = fb4_a = 0.*abs(lat_a2);
  fg4   = ft4   = elev*0.; fb4 = fg4 + 1.;
  w = where( lom>0. & elev<500. & mind<500. );
  fg4(w) = 0.4;
  ft4(w) = 0.4;
  w = where( lom>0. & elev>=500. & elev<1000. & mind<1000. );
  fg4(w) = 0.3;
  ft4(w) = 0.3;
  w = where( lom>0. & elev<1000. & mind>=500. & mind<1000. );
  fg4(w) = 0.3;
  ft4(w) = 0.3;
 
  // in addition to the distance/elevation limits above, we also
  // impose climatological limits in terms of temperature and
  // precipitation:
  infile = "Data/climatology_300yrs_"+timeslice+"_ts_coldestmonth.nc";
  d = nc_openf( infile, data, meta );
  ts_a = data.ts;
  infile = "Data/climatology_300yrs_"+timeslice+"_prc_annual.nc";
  d = nc_openf( infile, data, meta );
  prc_a = data.prc;
  // These are on the atmosphere grid, so we have to interpolate to
  // the ocean grid. First, we need to expand the arrays to ensure
  // periodic boundary conditions in longitude and proper
  // extrapolation at the poles:
  // construct expanded CLIMBER-3alpha atmosphere grid:
  lat_an = span( -93.75, +93.75, 26 );
  lon_an = span( -11.25, 371.25, 18 );
  // 2D arrays:
  lat_an2 = lat_an(-:1:numberof(lon_an),);
  lon_an2 = lon_an(,-:1:numberof(lat_an));
  // expand data arrays:
  ts_an = prc_an = lon_an2*0.;
  ts_an(2:17,2:25) = ts_a;       // middle part
  ts_an(2:17,0) = ts_a(,0);      // North pole
  ts_an(2:17,1) = ts_a(,1);      // South pole
  ts_an(18,) = ts_an(2,);        // longitude beyond 360
  ts_an(1,) = ts_an(-1,);        // longitude beyond 0
  prc_an(2:17,2:25) = prc_a;     // middle part
  prc_an(2:17,0) = prc_a(,0);    // North pole
  prc_an(2:17,1) = prc_a(,1);    // South pole
  prc_an(18,) = prc_an(2,);      // longitude beyond 360
  prc_an(1,) = prc_an(-1,);      // longitude beyond 0
  // interpolation:
  ts  = interp2( lat_2, lon_2, ts_an,  lat_an2, lon_an2 );
  prc = interp2( lat_2, lon_2, prc_an, lat_an2, lon_an2 );

  // we use the following limits: minimum annual precipitation
  // 700mm/year for all plant types; minimum monthly temperature -25
  // deg C. for trees:
  clim_g = ( prc < 700. );
  w = where( clim_g );
  fg2(w) = fg3(w) = fg4(w) = 0.;
  clim_t = ( prc < 700. | ts<-25. );
  w = where( clim_t );
  ft2(w) = ft3(w) = ft4(w) = 0.;

  // compute bare-land fraction on original grid for test plots:
  fb2 -= (fg2 + ft2);
  fb3 -= (fg3 + ft3);
  fb4 -= (fg4 + ft4);

  // compute surface type array for shading of vegetation cover;
  // values: 0: ocean (blue), 1: bare land (brown), 0 < type < 1: green
  // shading depending on grass and tree fraction:
  type2 = type3 = type4 = lom*1.0;
  w2 = where( fg2>0. | ft2>0. );
  type2(w2) = fg2(w2) + ft2(w2); // 60% + 0%; 10% + 0%; 0% + 0%
  w3 = where( fg3>0. | ft3>0. );
  type3(w3) = fg3(w3) + ft3(w3); // 70% + 10%; 0% + 0%
  w4 = where( fg4>0. | ft4>0. );
  type4(w4) = fg4(w4) + ft4(w4); // 40% + 40%; 30% + 30%; 0% + 0%


  // --------------------------------------------------------------------
  // MAKE PLOTS
  // --------------------------------------------------------------------

  // define color bar:
  r = [75];
  g = [75];
  b = [150];
  grow, r, span( 125,   0, 240 ); grow, r, [150];  // 125
  grow, g, span( 175,  75, 240 ); grow, g, [100];  //  75
  grow, b, array( 0, 240 ); grow, b, [50];         //  25
  
  // CASE 2:
  window, style="worldmap.gs";
  fma;
  pli, type2, -180, -90, 180, 90, cmin=0., cmax=1;
  //  plc, type2, lat_2, lon_2-180., levs=[.1,.6], color="black", width=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[0.49],
    color="black", width=2;
  plc, clim_t, lat_2, lon_2-180., levs=[.49], color="white", width=1;
  //  plc, clim_t, lat_2, lon_2-180., levs=[.49], color=[200,200,200], width=1;
  w = where( clim_t>0. & int(lat_2)%2==0 & int(lon_2)%2==0 );
  //  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.01, color=[200,200,200];//"white";
  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.05, color="white";
  palette, r, g, b;
  gridxy, base60=3;
  pltitle_height=14;
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  out = "Plots/"+timeslice+"_new_veg_case2"
  pdf, out;
  png, out, dpi=600;

  // CASE 3:
  fma;
  pli, type3, -180, -90, 180, 90, cmin=0., cmax=1;
  w = where( ft3>0. & int(lat_2+1)%4==0 & int(lon_2+1)%4==0 );
  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.05, color="black";//[0,40,10];
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.49], color="black", width=2;
  plc, clim_t, lat_2, lon_2-180., levs=[.49], color="white", width=1;
  //  plc, clim_t, lat_2, lon_2-180., levs=[.49], color=[200,200,200], width=1;
  w = where( clim_t>0. & int(lat_2)%2==0 & int(lon_2)%2==0 );
  //  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.01, color=[200,200,200];//"white";
  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.05, color="white";
  palette, r, g, b;
  gridxy, base60=3;
  pltitle_height=14;
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  out = "Plots/"+timeslice+"_new_veg_case3"
  pdf, out;
  png, out, dpi=600;

  // CASE 4:
  fma;
  pli, type4, -180, -90, 180, 90, cmin=0., cmax=1;
  w = where( ft4>0.3 & int(lat_2+1)%2==0 & int(lon_2+1)%2==0 );
  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.05, color="black";//[0,40,10];
  w = where( ft4>0. & ft4<0.4 & int(lat_2-1)%3==0 & int(lon_2-1)%3==0 );
  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.05, color="black";//[0,40,10];
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.49], color="black", width=2;
  plc, clim_t, lat_2, lon_2-180., levs=[.49], color="white", width=1;
  //  plc, clim_t, lat_2, lon_2-180., levs=[.49], color=[200,200,200], width=1;
  w = where( clim_t>0. & int(lat_2)%2==0 & int(lon_2)%2==0 );
  //  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.03, color=[200,200,200];//"white";
  plmk, lat_2(w), lon_2(w)-180., marker=4, msize=.05, color="white";
  palette, r, g, b;
  gridxy, base60=3;
  pltitle_height=14;
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  out = "Plots/"+timeslice+"_new_veg_case4"
  pdf, out;
  png, out, dpi=600;

  
}
