require, "asciilib.i";
require, "graphlib.i";
require, "geolib.i";
require, "climber3a.i";
include, "ncops.i";


//generates topography data and vegetation distribution for CLIMBER3alpha model runs
func devn_proc_topo( timeslice=, manualmode=, test1=, test2= )
{

  if( is_void(timeslice) )
    timeslice = "415Ma";


  // --------------------------------------------------------------------
  // READ TOPOGRAPHY INPUT DATA
  // --------------------------------------------------------------------

  // read topography data provided by Chris Scotese: the file format
  // changed at some point: for 415 Ma and 390 Ma the data are written
  // as (lat,lon,elev) whereas for the later times the format is
  // (lon,lat,elev)
  local lat1, lon1, elev1;
  if( timeslice=="415Ma" | timeslice=="390Ma" )
    read_columns, swrite( format="Data/%sPaleoDEMScotese.dat", timeslice ), 
      1,lat1, 2,lon1, 3,elev1;
  if( timeslice=="380Ma" | timeslice=="360Ma" )
    read_columns, swrite( format="Data/%sPaleoDEMScotese.dat", timeslice ), 
      1,lon1, 2,lat1, 3,elev1;


  // --------------------------------------------------------------------
  // CREATE ARRAYS
  // --------------------------------------------------------------------

  // the original data are on a 1-degree resolution:
  lat = span( -89.5, 89.5, 180 );
  lon = span( 0.5, 359.5, 360 );
  // NB: original data are from -180 to +180 in longitude, we just shift
  // the coordinate system by 180 degrees to facilitate interpolation
  // on model grid ranging from 0 to 360
  // 2D arrays of original grid (only used for Arctic test!):
  lat_2 = lat(-:1:numberof(lon),);
  lon_2 = lon(,-:1:numberof(lat));

  // create 2D array from input data file: the data are stored in one
  // column, but the file format changed at some point:
  // 415 Ma, 390 Ma: longitudes range from -179.5 to +179.5, latitudes
  // from +89.5 to -89.5; 
  elev = array( 0., 360, 180 );
  if( timeslice=="415Ma" | timeslice=="390Ma" )
    for( nlat=1; nlat<180; nlat++ )
      elev(,180-nlat+1) = elev1( ((nlat-1)*360+1):(nlat*360) );
  // 380 Ma, 360 Ma: longitudes range from -180 to +180, latitudes
  // from +90 to -90; all values for longitude -180 have value zero,
  // so we rearrange to an array with dimensions [360,180]:
  if( timeslice=="380Ma" | timeslice=="360Ma" )
    for( nlat=1; nlat<=180; nlat++ )
      elev(,180-nlat+1) = elev1( ((nlat-1)*361+2):(nlat*361) );

  // test 1: remove islands and land areas close to the Arctic:
  if( !is_void(test1) ){
    w = where( lat_2>23. | (lat_2>15. & lon_2>150. & lon_2<200.) );
    elev(w) = -3480.;
  }

  // construct land-ocean mask:
  lom = ( elev>0. );

  // compute and output land fraction:
  sum(get_geo_weights(360,180)*lom);

  // get median land elevation and ocean depth on the original grid:
  // old version (average):
  //  wgt = get_geo_weights( numberof(lon), numberof(lat) );
  //  melev_l = sum( wgt*lom*elev )/sum( wgt*lom );
  //  melev_o = sum( wgt*(1.-lom)*elev )/sum( wgt*(1.-lom) );
  // new version (median):
  melev_l = median(elev(where(lom)));
  melev_o = median(elev(where(!lom)));

  // copied from cretaceous.i:
  // expand arrays to ensure periodic boundary conditions in longitude
  // and proper extrapolation at the poles:
  nlat = numberof(lat);
  nlon = numberof(lon);
  dlat = lat(2)-lat(1);
  dlon = lon(2)-lon(1);
  lat_n = [lat(1)-dlat];
  grow, lat_n, lat, [lat(0)+dlat];
  lon_n = [lon(1)-dlon];
  grow, lon_n, lon, [lon(0)+dlon];

  elev_n = array( 0., nlon+2, nlat+2 );
  elev_n(2:nlon+1,2:nlat+1) = elev;  // middle part
  elev_n(2:nlon+1,0) = elev(,0);     // North pole
  elev_n(2:nlon+1,1) = elev(,1);     // South pole
  elev_n(nlon+2,) = elev_n(2,);      // longitude beyond 360
  elev_n(1,) = elev_n(-1,);          // longitude beyond 0

  lom_n = array( 0., nlon+2, nlat+2 );
  lom_n(2:nlon+1,2:nlat+1) = lom;    // middle part
  lom_n(2:nlon+1,0) = lom(,0);       // North pole
  lom_n(2:nlon+1,1) = lom(,1);       // South pole
  lom_n(nlon+2,) = lom_n(2,);        // longitude beyond 360
  lom_n(1,) = lom_n(-1,);            // longitude beyond 0

  // 2D arrays of expanded data grid at original resolution:
  lat_n2 = lat_n(-:1:numberof(lon_n),);
  lon_n2 = lon_n(,-:1:numberof(lat_n));

  // construct CLIMBER-3alpha ocean grid:
  lat_o = span( -88.125, +88.125, 48 );
  lon_o = span( 1.875, 358.125, 96 );
  // 2D arrays:
  lat_o2 = lat_o(-:1:numberof(lon_o),);
  lon_o2 = lon_o(,-:1:numberof(lat_o));

  // construct CLIMBER-3alpha atmosphere grid:
  lat_a = span( -86.25, +86.25, 24 );
  lon_a = span( 11.25, 348.75, 16 );
  // 2D arrays:
  lat_a2 = lat_a(-:1:numberof(lon_a),);
  lon_a2 = lon_a(,-:1:numberof(lat_a));

  // only for test plot: atmosphere grid corners:
  lat_ac = span( -90., 90., 25 );
  lon_ac = span( 0., 360., 17 );
  // 2D arrays:
  lat_ac2 = lat_ac(-:1:numberof(lon_ac),);
  lon_ac2 = lon_ac(,-:1:numberof(lat_ac));



  // --------------------------------------------------------------------
  // INTERPOLATE TO MODEL GRID
  // --------------------------------------------------------------------

  // interpolate elevation and land-ocean mask onto the CLIMBER-3alpha
  // ocean grid:
  elev_o = interp2( lat_o2, lon_o2, elev_n, lat_n2, lon_n2 );
  lom_o  = interp2( lat_o2, lon_o2, lom_n, lat_n2, lon_n2 );

  // temporarily expand these arrays to enable search for neighbouring
  // ocean or land grid cells:
  elev_on = array( 0., 98, 50 );
  elev_on(2:97,2:49) = elev_o;      // middle part
  elev_on(2:97,0) = elev_o(,0);     // North pole
  elev_on(2:97,1) = elev_o(,1);     // South pole
  elev_on(98,) = elev_on(2,);       // longitude beyond 360
  elev_on(1,) = elev_on(-1,);       // longitude beyond 0
  lom_on = array( 0., 98, 50 );
  lom_on(2:97,2:49) = lom_o;        // middle part
  lom_on(2:97,0) = lom_o(,0);       // North pole
  lom_on(2:97,1) = lom_o(,1);       // South pole
  lom_on(98,) = lom_on(2,);         // longitude beyond 360
  lom_on(1,) = lom_on(-1,);         // longitude beyond 0

  // in the land-ocean mask, set pixels with small land fraction to 0
  // (ocean) and with high land fraction to 1 (land):
  limit_ocean_land = 0.5;
  // new ocean cells:
  w = where( lom_o>0. & lom_o<limit_ocean_land );
  lom_o(w) = 0.;
  // ... and assign an elevation which is the average of neigbouring
  // ocean cells:
  for( n=1; n<=numberof(w); n++ ){
    ilon = where( lon_o==lon_o2(w(n)) )(1);
    ilat = where( lat_o==lat_o2(w(n)) )(1);
    ocean = ( lom_on<=0.05 );
    if( sum( ocean(ilon:ilon+2,ilat:ilat+2) ) )
      elev_o(w(n)) = sum( (elev_on*ocean)(ilon:ilon+2,ilat:ilat+2) )/
        sum( ocean(ilon:ilon+2,ilat:ilat+2) );
    else
      elev_o(w(n)) = melev_o;
  }
  // new land cells:
  w = where( lom_o>=limit_ocean_land & lom_o<1. );
  lom_o(w) = 1.;
  // ... and assign an elevation which is the average of neigbouring
  // land cells:
  for( n=1; n<=numberof(w); n++ ){
    ilon = where( lon_o==lon_o2(w(n)) )(1);
    ilat = where( lat_o==lat_o2(w(n)) )(1);
    land = ( lom_on>=0.95 );
    if( sum( land(ilon:ilon+2,ilat:ilat+2) ) )
      elev_o(w(n)) = sum( (elev_on*land)(ilon:ilon+2,ilat:ilat+2) )/
        sum( land(ilon:ilon+2,ilat:ilat+2) );
    else
      elev_o(w(n)) = melev_l;
  }
  lom_o = int(lom_o);

  // assign interpolated topography values to CLIMBER-3alpha ocean
  // depth levels:
  read_columns, "~/Climate/Projects/ACE/Cretaceous/Data/mom_depth_levels.dat", 
    1,k, 2,z, 4,z_top;
  depth = elev_o*0;
  for( n=1; n<=24; n++ ){
    w = where( elev_o<-z_top(n) );
    if( numberof(w) )
      depth(w) = n;
  }

  // there could be one more complication for this time period: the
  // PaleoDEMs provided by Chris Scotese have a very flat deep ocean
  // part over major parts of the Earth. To avoid model instability we
  // introduce artificial fluctuations in the ocean depth levels:
  w = where( depth==21 );
  depth(w) = round(random(numberof(w))+20.);
  w = where( depth==20 );
  depth(w) = round(random(numberof(w))*2.+19.);
  // except for the North pole, which we set at a uniform depth (as
  // for the Neoproterozoic):
  depth(,48) = 20;

  // multiply this depth-level field by the inverse land-ocean mask to
  // make sure that interpolated pixels which are assigned to be land
  // do not get a depth value:
  depth *= (1-lom_o);

  // store original depth and land-ocean mask arrays for reference
  // before doing manual adjustments:
  depth_unadj = depth;
  lom_o_unadj = lom_o;
  elev_o_unadj = elev_o;

  // avoid very shallow ocean cells with depth less than 100 m:
  w = where( depth>0 & depth<5 );
  if( numberof(w) )
    depth(w) = 5;

  // manual adjustments:
  if( timeslice=="415Ma" ){
    // isolated ocean cell on Southern continent:
    depth(85,4) = 0;
    // open narrow ocean arm close to Southern continent:
    depth(26,2) = 4;
    depth(27,3) = 5;
    depth(28:31,3) = depth(28:31,4);
    depth(28:31,4) = 0;
    depth(31,2) = 5;
    depth(35:37,3) = 5;
    depth(34,2) = 5;
    depth(32,5) = 0;
    // adjustments to island chain towards the West of the Southern continent:
    depth(11:13,10) = 5;
    depth(15:18,9) = 0;
    depth(13,11) = 5;
    depth(19,10) = 0;
    depth(13:14,13) = 0;
    depth(17,8) = 0;
    // minor adjustments at the Eastern side of the Southern continent:
    depth(72:73,4) = 5;
    depth(80,12) = 0;
    depth(80,14) = 5;
    depth(76:78,17) = 5;
    // reconstruct island chains North-East of the equatorial continent:
    depth(58,35) = 0;
    depth(64,33) = 0;
    depth(62,30) = 0;
    depth(61,36) = 0;
    depth(63,35) = 0;
    depth(56,24) = 0;
    depth(55,26) = 0;
    depth(53,28) = 0;
    depth(51,29) = 0;
    depth(58,26:27) = 0;
    // equatorial continent:
    depth(40,15) = 0;
    depth(41:42,16) = 0;
    depth(49,21) = 0;
    depth(39,22) = 5;
    depth(43,26) = 0;
    depth(45,25) = 0;
  }
  if( timeslice=="380Ma" ){
    // isolated ocean cell on Southern continent:
    depth(80,6) = 0;
    depth(83:84,19) = 0;
    // isolated ocean cell on Eastern landmass:
    depth(78,24) = 0;
    // islands:
    depth(59,28) = 0;
    depth(61,26) = 0;
    depth(62,27) = 0;
    depth(64,29) = 0;
    if( is_void(test1) )
      depth(65,32) = 0;
    depth(54,23) = 0;
    depth(40,22) = 0;
    // land bridge to Southern continent:
    depth(42,15) = 0;
    depth(43,12) = depth(41,12);
    // long landmass to the North of the Southern continent:
    depth(29,9) = 0;
    // Southern continent:
    depth(37:40,8) = 0;
    depth(50,6) = 0;
    depth(48,7) = depth(47,7);
    depth(36:38,2) = 5;
    depth(87,10) = 5;
    depth(87,7) = 0;
    depth(84,6) = 0;
    depth(86:87,2) = 0;
  }
  if( timeslice=="360Ma" ){
    // shelf around the South pole:
    depth(43:59,1) = depth(42,1);
    depth(6,6) = depth(5,6);
    depth(21,6) = depth(20,6);

    depth(41,24) = 5;
    depth(46,8) = 0;
    depth(47,9) = 0;
    depth(47,17) = 0;
    depth(45,26) = 0;
    depth(46:47,28) = 0;

    depth(78,5) = 0;

    depth(30,11) = depth(29,11);
    depth(31,9) = depth(32,9);
    depth(32,11) = depth(32,10);
    depth(32,12) = depth(32,13);
    depth(34,10) = 0;

    depth(53,34) = depth(54,34);

    // islands:
    depth(55,28) = 0;
    depth(68,34) = 0;
    depth(65:66,34) = 0;
    depth(52,30) = depth(52,29);
    depth(52,29) = 0;

    // peanut island:
    depth(49,16) = depth(50,16);
    depth(49,20) = depth(50,20);
    depth(48,19:20) = depth(49,20);
    depth(49,21) = depth(50,20);
    depth(50,21) = depth(51,21);
    depth(52,19) = depth(53,19);

    // ocean trench:
    depth(74:76,21) += 5;
    depth(79,24) += 5;

  }

  // test 2: place a circular island on the Northern pole:
  if( !is_void(test2) )
    depth(,48) = 0;

  // check for inconsistencies between elevation array and land-ocean
  // mask and update land-ocean mask after manual adjustments:
  w = where( depth>0. & lom_o==1 ); // new ocean cells
  if( numberof(w) ){
    lom_o(w)  = 0;
    elev_o(w) = melev_o;
  }
  w = where( depth==0 & lom_o==0 ); // new land cells
  if( numberof(w) ){
    lom_o(w)  = 1;
    elev_o(w) = melev_l;
  }

  // compute and output land fraction on ocean grid:
  sum(get_geo_weights(96,48)*lom_o);
  

  // --------------------------------------------------------------------
  // GENERATE VEGETATION DISTRIBUTIONS
  // --------------------------------------------------------------------

  // OK, for the assignment of vegetation for the Devonian we need a
  // measure for the minimum distance from the coast for each land
  // cell on the original grid; here is the definition of the original
  // grid from above:
  //  lat = span( -89.5, 89.5, 180 );
  //  lon = span( 0.5, 359.5, 360 );
  // 2D arrays:
  //  lat_2 = lat(-:1:numberof(lon),);
  //  lon_2 = lon(,-:1:numberof(lat));
  // these are in degrees, we need them in radians:
  lat_2r = lat_2/180.*pi;
  lon_2r = lon_2/180.*pi;
  // we have to do this for all land cells on the original grid:
  w = where( lom>0. ); // select land cells
  // set Earth radius (km):
  re = 6371.;
  // initialise minimum distance array:
  mind = lom;
  for( n=1; n<=numberof(w); n++ ){
    // compute 2D distance matrix:
    t = sin(lat_2r)*sin(lat_2r(w(n))) + 
      cos(lat_2r)*cos(lat_2r(w(n)))*cos(lon_2r-lon_2r(w(n)));
    // sometimes rounding errors cause the acos function to crash:
    ww = where( t>1. );
    if(numberof(ww))
      t(ww)=1.;
    ww = where( t<-1. );
    if(numberof(ww))
      t(ww)=-1.;
    dist2 = re * acos( t );
    
    mind(w(n)) = min(dist2(where(lom==0)));
  }

  // assign tree, grass and bare-land fractions on the CLIMBER-3alpha
  // atmosphere grid; this is the corrected version:
  fl_a = 0.*abs(lat_a2);
  //
  // CASE 1: we assume zero vegetation in this case, assignment
  // directly on the atmosphere grid:
  //
  ft1_a = fg1_a = fb1_a = 0.*abs(lat_a2);
  //
  // CASE 2: Early Devonian
  //     0km <= d < 300km,   0m <= e < 300m: 60% grass 
  //                                         (2/3 bryophytes, 1/3 shrubs)
  //            d < 500km, 300m <= e < 500m: 10% grass 
  //                                         (2/3 bryophytes, 1/3 shrubs)
  //   300km <  d < 500km,         e < 500m: 10% grass 
  //                                         (2/3 bryophytes, 1/3 shrubs)
  //   500km <= d,         500m <= e:        bare land
  //
  ft2_a = fg2_a = fb2_a = 0.*abs(lat_a2);
  fg2   = ft2   = elev*0.; fb2 = fg2 + 1.;
  w = where( lom>0. & elev<300. & mind<300. );
  fg2(w) = 0.6;
  ft2(w) = 0.0;
  w = where( lom>0. & elev>=300. & elev<500. & mind<500. );
  fg2(w) = 0.1;
  ft2(w) = 0.0;
  w = where( lom>0. & elev<500. & mind>=300. & mind<500. );
  fg2(w) = 0.1;
  ft2(w) = 0.0;
  //
  // CASE 3: Middle Devonian
  //     0km <= d < 500km,   0m <= e < 500m: 70% grass 
  //                                         (4/5 shrubs+1/5 bryophytes),
  //                                         10% trees (small trees/tall grass)
  //   500km <= d,         500m <= e:        bare land
  //
  ft3_a = fg3_a = fb3_a = 0.*abs(lat_a2);
  fg3   = ft3   = elev*0.; fb3 = fg3 + 1.;
  w = where( lom>0. & elev<500. & mind<500. );
  fg3(w) = 0.7;
  ft3(w) = 0.1;
  //
  // CASE 4: Late Devonian
  //      0km <= d <  500km,    0m <= e <  500m: 40% grass 
  //                                             (4/5 shrubs+1/5 bryophytes),
  //                                             40% trees
  //             d < 1000km,  500m <= e < 1000m: 30% grass 
  //                                             (4/5 shrubs+1/5 bryophytes),
  //                                             30% trees
  //    500km    d < 1000km,          e < 1000m: 30% grass 
  //                                             (4/5 shrubs+1/5 bryophytes),
  //                                             30% trees
  //   1000km <= d,          1000m <= e:         bare land
  //
  ft4_a = fg4_a = fb4_a = 0.*abs(lat_a2);
  fg4   = ft4   = elev*0.; fb4 = fg4 + 1.;
  w = where( lom>0. & elev<500. & mind<500. );
  fg4(w) = 0.4;
  ft4(w) = 0.4;
  w = where( lom>0. & elev>=500. & elev<1000. & mind<1000. );
  fg4(w) = 0.3;
  ft4(w) = 0.3;
  w = where( lom>0. & elev<1000. & mind>=500. & mind<1000. );
  fg4(w) = 0.3;
  ft4(w) = 0.3;
 
  // in addition to the distance/elevation limits above, we also
  // impose climatological limits in terms of temperature and
  // precipitation:
  infile = "Data/climatology_300yrs_"+timeslice+"_ts_coldestmonth.nc";
  d = nc_openf( infile, data, meta );
  ts_a = data.ts;
  infile = "Data/climatology_300yrs_"+timeslice+"_prc_annual.nc";
  d = nc_openf( infile, data, meta );
  prc_a = data.prc;
  // These are on the atmosphere grid, so we have to interpolate to
  // the ocean grid. First, we need to expand the arrays to ensure
  // periodic boundary conditions in longitude and proper
  // extrapolation at the poles:
  // construct expanded CLIMBER-3alpha atmosphere grid:
  lat_an = span( -93.75, +93.75, 26 );
  lon_an = span( -11.25, 371.25, 18 );
  // 2D arrays:
  lat_an2 = lat_an(-:1:numberof(lon_an),);
  lon_an2 = lon_an(,-:1:numberof(lat_an));
  // expand data arrays:
  ts_an = prc_an = lon_an2*0.;
  ts_an(2:17,2:25) = ts_a;       // middle part
  ts_an(2:17,0) = ts_a(,0);      // North pole
  ts_an(2:17,1) = ts_a(,1);      // South pole
  ts_an(18,) = ts_an(2,);        // longitude beyond 360
  ts_an(1,) = ts_an(-1,);        // longitude beyond 0
  prc_an(2:17,2:25) = prc_a;     // middle part
  prc_an(2:17,0) = prc_a(,0);    // North pole
  prc_an(2:17,1) = prc_a(,1);    // South pole
  prc_an(18,) = prc_an(2,);      // longitude beyond 360
  prc_an(1,) = prc_an(-1,);      // longitude beyond 0
  // interpolation:
  ts  = interp2( lat_2, lon_2, ts_an,  lat_an2, lon_an2 );
  prc = interp2( lat_2, lon_2, prc_an, lat_an2, lon_an2 );

  // we use the following limits: minimum annual precipitation
  // 700mm/year for all plant types; minimum monthly temperature -25
  // deg C. for trees:
  clim_g = ( prc < 700. );
  w = where( clim_g );
  fg2(w) = fg3(w) = fg4(w) = 0.;
  clim_t = ( prc < 700. | ts<-25. );
  w = where( clim_t );
  ft2(w) = ft3(w) = ft4(w) = 0.;

  // compute bare-land fraction on original grid for test plots:
  fb2 -= (fg2 + ft2);
  fb3 -= (fg3 + ft3);
  fb4 -= (fg4 + ft4);

  // compute/assign vegetation fractions on atmosphere grid for all
  // cases:
  // these are the grid definitions from above:
  // original grid:
  //  lat = span( -89.5, 89.5, 180 );
  //  lon = span( 0.5, 359.5, 360 );
  // atmosphere grid:
  //  lat_a = span( -86.25, +86.25, 24 );
  //  lon_a = span( 11.25, 348.75, 16 );
  for( nlon=1; nlon<=16; nlon++ ){
    for( nlat=1; nlat<=24; nlat++ ){
      w1p00 = where( lon_2>lon_a(nlon)-11.25 & lon_2<lon_a(nlon)+11.25 &
                     lat_2>lat_a(nlat)-3.75  & lat_2<lat_a(nlat)+3.75 );
      w0p50 = where( ( lon_2==lon_a(nlon)-11.25 & 
                       lat_2>lat_a(nlat)-3.75  & lat_2<lat_a(nlat)+3.75 ) |
                     ( lon_2==lon_a(nlon)+11.25 &
                       lat_2>lat_a(nlat)-3.75  & lat_2<lat_a(nlat)+3.75 ) |
                     ( lon_2>lon_a(nlon)-11.25 & lon_2<lon_a(nlon)+11.25 &
                       lat_2==lat_a(nlat)-3.75 ) |
                     ( lon_2>lon_a(nlon)-11.25 & lon_2<lon_a(nlon)+11.25 &
                       lat_2==lat_a(nlat)+3.75 ) );
      w0p25 = where( ( lon_2==lon_a(nlon)-11.25 & lat_2==lat_a(nlat)-3.75 ) |
                     ( lon_2==lon_a(nlon)-11.25 & lat_2==lat_a(nlat)+3.75 ) |
                     ( lon_2==lon_a(nlon)+11.25 & lat_2==lat_a(nlat)-3.75 ) |
                     ( lon_2==lon_a(nlon)+11.25 & lat_2==lat_a(nlat)+3.75 ) );
      fl_a(nlon,nlat) = ( 1.00*lom(w1p00)(sum) + 
                          0.50*lom(w0p50)(sum) +
                          0.25*lom(w0p25)(sum) )/168.75;
      // CASE 1: nothing to do because everything is bare land
      // CASE 2:
      ft2_a(nlon,nlat) = ( 1.00*ft2(w1p00)(sum) + 
                           0.50*ft2(w0p50)(sum) +
                           0.25*ft2(w0p25)(sum) )/168.75;
      fg2_a(nlon,nlat) = ( 1.00*fg2(w1p00)(sum) + 
                           0.50*fg2(w0p50)(sum) +
                           0.25*fg2(w0p25)(sum) )/168.75;
      // CASE 3:
      ft3_a(nlon,nlat) = ( 1.00*ft3(w1p00)(sum) + 
                           0.50*ft3(w0p50)(sum) +
                           0.25*ft3(w0p25)(sum) )/168.75;
      fg3_a(nlon,nlat) = ( 1.00*fg3(w1p00)(sum) + 
                           0.50*fg3(w0p50)(sum) +
                           0.25*fg3(w0p25)(sum) )/168.75;
      // CASE 4:
      ft4_a(nlon,nlat) = ( 1.00*ft4(w1p00)(sum) + 
                           0.50*ft4(w0p50)(sum) +
                           0.25*ft4(w0p25)(sum) )/168.75;
      fg4_a(nlon,nlat) = ( 1.00*fg4(w1p00)(sum) + 
                           0.50*fg4(w0p50)(sum) +
                           0.25*fg4(w0p25)(sum) )/168.75;
    }
  }

  // Normalisation. Here we have to keep in mind that tree/grass
  // fractions in CLIMBER-3alpha are defined relativ to the land area
  // (!); for example, to calculate the grass fraction in a mixed
  // land/ocean cell on the atmospheric grid, the model would multiply
  // the grass fraction as defined here with the land fraction. So far
  // we have defined tree/grass fractions relative to the entire grid
  // cell, so we have to divide by the land fraction in each cell:
  w = where( fl_a>0. );
  // CASE 1: no normalisation required because everything is bare land:
  fb1_a(w) = 1.-ft1_a(w)-fg1_a(w);
  // CASE 2:
  ft2_a(w) /= fl_a(w);
  fg2_a(w) /= fl_a(w);
  fb2_a(w) = 1.-ft2_a(w)-fg2_a(w);
  // CASE 3:
  ft3_a(w) /= fl_a(w);
  fg3_a(w) /= fl_a(w);
  fb3_a(w) = 1.-ft3_a(w)-fg3_a(w);
  // CASE 4:
  ft4_a(w) /= fl_a(w);
  fg4_a(w) /= fl_a(w);
  fb4_a(w) = 1.-ft4_a(w)-fg4_a(w);


  // --------------------------------------------------------------------
  // WRITE OUTPUT FILES
  // --------------------------------------------------------------------

  // write ocean depth levels to file kmt.dta:
  if( !is_void(test1) )
    out_kmt = "ModelInput/"+timeslice+"_kmt_test1.dta";
  else if( !is_void(test2) )
    out_kmt = "ModelInput/"+timeslice+"_kmt_test2.dta";
  else
    out_kmt = "ModelInput/"+timeslice+"_kmt.dta";
  c3a_write_kmt, out_kmt, depth;

  // write land orography data into ASCII file (longitudes are in
  // columns, units are converted from m to cm):
  oro_o = elev_o*lom_o;
  // ocean areas:
  w = where( oro_o<1. );
  // There is a slight complication: During initialisation, MOM3
  // checks for "holes" in ocean bathymetry and "fills" them. This
  // can sometimes change the land-ocean mask by creating a few new
  // land grid cells. If we set ocean cells in oro.dat to 0, then
  // these new land cells end up with height 0. To avoid this minor
  // problem, we set all ocean cells to the average land elevation
  // (remaining ocean cells will be set to 0 during model
  // initialisation anyway).
  oro_o(w) = melev_l;

  if( !is_void(test1) )
    out_oro = "ModelInput/"+timeslice+"_oro_test1.dat"; 
  else if( !is_void(test2) )
    out_oro = "ModelInput/"+timeslice+"_oro_test2.dat"; 
  else
    out_oro = "ModelInput/"+timeslice+"_oro.dat"; 
  f = open( out_oro, "w" );
  write, f, format=" %6.4e", oro_o*100., linesize=11*numberof(lon_o);
  close, f;

  // write tree, grass and bare-land fractions into ASCII file:
  // CASE 1:
  if( !is_void(test1) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_bare_test1.dat";
  else if( !is_void(test2) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_bare_test2.dat";
  else
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_bare.dat";
  f = open( out_veg, "w" );
  lsize = 9*numberof(lon_a);
  first=1;
  for( n=numberof(lat_a); n>=1; n-- ){
    write, f, format="%9.5f", abs(ft1_a(,n)), linesize=lsize;
    write, f, format="%9.5f", abs(fg1_a(,n)), linesize=lsize;
    for( m=1; m<=numberof(lon_a); m++ ){
      if( m<numberof(lon_a) )
        write, f, format="%9.5f", abs(fb1_a(m,n)), linesize=lsize;
      else
        write, f, format="%9.5f\n", abs(fb1_a(m,n)), linesize=lsize;
    }
  }
  close, f;
  // CASE 2:
  if( !is_void(test1) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_edev_test1.dat";
  else if( !is_void(test2) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_edev_test2.dat";
  else
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_edev.dat";
  f = open( out_veg, "w" );
  lsize = 9*numberof(lon_a);
  first=1;
  for( n=numberof(lat_a); n>=1; n-- ){
    write, f, format="%9.5f", abs(ft2_a(,n)), linesize=lsize;
    write, f, format="%9.5f", abs(fg2_a(,n)), linesize=lsize;
    for( m=1; m<=numberof(lon_a); m++ ){
      if( m<numberof(lon_a) )
        write, f, format="%9.5f", abs(fb2_a(m,n)), linesize=lsize;
      else
        write, f, format="%9.5f\n", abs(fb2_a(m,n)), linesize=lsize;
    }
  }
  close, f;
  // CASE 3:
  if( !is_void(test1) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_mdev_test1.dat";
  else if( !is_void(test2) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_mdev_test2.dat";
  else
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_mdev.dat";
  f = open( out_veg, "w" );
  lsize = 9*numberof(lon_a);
  first=1;
  for( n=numberof(lat_a); n>=1; n-- ){
    write, f, format="%9.5f", abs(ft3_a(,n)), linesize=lsize;
    write, f, format="%9.5f", abs(fg3_a(,n)), linesize=lsize;
    for( m=1; m<=numberof(lon_a); m++ ){
      if( m<numberof(lon_a) )
        write, f, format="%9.5f", abs(fb3_a(m,n)), linesize=lsize;
      else
        write, f, format="%9.5f\n", abs(fb3_a(m,n)), linesize=lsize;
    }
  }
  close, f;
  // CASE 4:
  if( !is_void(test1) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_ldev_test1.dat";
  else if( !is_void(test2) )
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_ldev_test2.dat";
  else
    out_veg = "ModelInput/"+timeslice+"_p2_vegetat_obs_ldev.dat";
  f = open( out_veg, "w" );
  lsize = 9*numberof(lon_a);
  first=1;
  for( n=numberof(lat_a); n>=1; n-- ){
    write, f, format="%9.5f", abs(ft4_a(,n)), linesize=lsize;
    write, f, format="%9.5f", abs(fg4_a(,n)), linesize=lsize;
    for( m=1; m<=numberof(lon_a); m++ ){
      if( m<numberof(lon_a) )
        write, f, format="%9.5f", abs(fb4_a(m,n)), linesize=lsize;
      else
        write, f, format="%9.5f\n", abs(fb4_a(m,n)), linesize=lsize;
    }
  }
  close, f;

  // --------------------------------------------------------------------
  // MAKE TEST PLOTS
  // --------------------------------------------------------------------

  // original topography:
  window, 0, style="worldmap.gs";
  fma;
  colorbar_, -5000, 5000, viewport=[0.20,0.60,0.42,0.43], 
    nmajor=10, nminor=0, tlabel_b=1, horizontal=1,
      tlabel_height=12;
  plt, "m", 0.606, 0.400, tosys=0, height=12;
  pli, elev, -180, -90, 180, 90, cmin=-5000., cmax=5000;
  r = span( 0, 120, 120 ); grow, r, span( 100, 255, 120 );
  g = span( 0, 120, 120 ); grow, g, span( 75, 175, 120 );
  b = span( 120, 255, 120 ); grow, b, array( 0, 120 );
  palette, r,g,b;
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Topography (original resolution)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_topog";
  png, "Plots/"+timeslice+"_ini_grid_topog", dpi=600;

  // topography (ocean grid):
  window, 1, style="worldmap.gs";
  fma;
  colorbar_, -5000, 5000, viewport=[0.20,0.60,0.42,0.43], 
    nmajor=10, nminor=0, tlabel_b=1, horizontal=1,
      tlabel_height=12;
  plt, "m", 0.606, 0.400, tosys=0, height=12;
  pli, elev_o_unadj, -180, -90, 180, 90, cmin=-5000., cmax=5000;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  r = span( 0, 120, 120 ); grow, r, span( 100, 255, 120 );
  g = span( 0, 120, 120 ); grow, g, span( 75, 175, 120 );
  b = span( 120, 255, 120 ); grow, b, array( 0, 120 );
  palette, r, g, b;
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Topography (ocean grid, before adjustments)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ocn_grid_topog";
  png, "Plots/"+timeslice+"_ocn_grid_topog", dpi=600;

  // land-ocean mask (original resolution):
  window, 2, style="worldmap.gs";
  fma;
  pli, lom, -180, -90, 180, 90;
  palette, "earth.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land-ocean mask (original resolution)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_lom";
  png, "Plots/"+timeslice+"_ini_grid_lom", dpi=600;

  // land-ocean mask (ocean grid)
  window, 3, style="worldmap.gs";
  fma;
  pli, lom_o, -180, -90, 180, 90;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  palette, "earth.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land-ocean mask (ocean grid, after adjustments)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ocn_grid_lom";
  png, "Plots/"+timeslice+"_ocn_grid_lom", dpi=600;

  // MOM3 depth levels (ocean grid):
  window, 4, style="worldmap.gs";
  fma;
  colorbar_, -24, 0, viewport=[0.20,0.60,0.42,0.43], 
    nmajor=10, nminor=0, tlabel_b=1, horizontal=1,
      tlabel_height=12;
  if( is_void(manualmode) ){
    pli, -depth,  -180, -90, 180, 90, cmin=-24, cmax=0.1;
    plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  }
  else
    pli, -depth, 1, 1, 97, 49, cmin=-24, cmax=0.1;
  r = span( 0, 120, 239 ); grow, r, [255,120];
  g = span( 0, 120, 239 ); grow, g, [255,120];
  b = span( 50, 255, 239 ); grow, b, [255,120];
  palette, r,g,b;
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Ocean model depth levels (kmt.dta, after adjustments)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ocn_grid_kmt";
  png, "Plots/"+timeslice+"_ocn_grid_kmt", dpi=600;

  // manual changes to MOM3 depth levels (ocean grid):
  window, 5, style="worldmap.gs";
  fma;
  colorbar_, -24, 0, viewport=[0.20,0.60,0.42,0.43], 
    nmajor=10, nminor=0, tlabel_b=1, horizontal=1,
      tlabel_height=12;
  diff = depth-depth_unadj;
  newland = ( diff<0. & depth==0 )*(-5.);
  newocean = ( diff!=0. )*depth;
  new = newland+newocean
  pli, -new,  -180, -90, 180, 90, cmin=-24, cmax=0.1;
  plc, lom_o_unadj, lat_o2, lon_o2-180., levs=[.6],
    type="dash";
  plc, lom_o, lat_o2, lon_o2-180., levs=[.4];
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  r = span( 0, 120, 239 ); grow, r, [255,120];
  g = span( 0, 120, 239 ); grow, g, [255,120];
  b = span( 50, 255, 239 ); grow, b, [255,120];
  palette, r,g,b;
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Manually adjusted ocean depth levels";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ocn_grid_kmt_manual";
  png, "Plots/"+timeslice+"_ocn_grid_kmt_manual", dpi=600;

  // final orography (ocean grid, after adjustments):
  window, 6, style="worldmap.gs";
  fma;
  colorbar_, -5000, 5000, viewport=[0.20,0.60,0.42,0.43], 
    nmajor=10, nminor=0, tlabel_b=1, horizontal=1,
      tlabel_height=12;
  plt, "m", 0.606, 0.400, tosys=0, height=12;
  pli, oro_o*lom_o, -180, -90, 180, 90, cmin=-5000., cmax=5000;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  r = span( 0, 120, 120 ); grow, r, span( 100, 255, 120 );
  g = span( 0, 120, 120 ); grow, g, span( 75, 175, 120 );
  b = span( 120, 255, 120 ); grow, b, array( 0, 120 );
  palette, r, g, b;
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Orography (ocean grid, after adjustments)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ocn_grid_oro";
  png, "Plots/"+timeslice+"_ocn_grid_oro", dpi=600;

  // CASE 1: tree fraction (atmosphere grid):
  window, 7, style="worldmap.gs";
  fma;
  pli, ft1_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model tree fraction (case 1, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_ftrees_case1";
  png, "Plots/"+timeslice+"_atm_grid_ftrees_case1", dpi=600;

  // CASE 1: grass fraction (atmosphere grid):
  fma;
  pli, fg1_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model grass fraction (case 1, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fgrass_case1";
  png, "Plots/"+timeslice+"_atm_grid_fgrass_case1", dpi=600;

  // CASE 1: bare-land fraction (atmosphere grid):
  fma;
  pli, fb1_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model bare land fraction (case 1, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fbare_case1";
  png, "Plots/"+timeslice+"_atm_grid_fbare_case1", dpi=600;
  
  // CASE 2: tree fraction (atmosphere grid):
  fma;
  pli, ft2_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model tree fraction (case 2, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_ftrees_case2";
  png, "Plots/"+timeslice+"_atm_grid_ftrees_case2", dpi=600;

  // CASE 2: grass fraction (atmosphere grid):
  fma;
  pli, fg2_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model grass fraction (case 2, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fgrass_case2";
  png, "Plots/"+timeslice+"_atm_grid_fgrass_case2", dpi=600;

  // CASE 2: bare-land fraction (atmosphere grid):
  fma;
  pli, fb2_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model bare land fraction (case 2, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fbare_case2";
  png, "Plots/"+timeslice+"_atm_grid_fbare_case2", dpi=600;
  
  // CASE 3: tree fraction (atmosphere grid):
  fma;
  pli, ft3_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model tree fraction (case 3, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_ftrees_case3";
  png, "Plots/"+timeslice+"_atm_grid_ftrees_case3", dpi=600;

  // CASE 3: grass fraction (atmosphere grid):
  fma;
  pli, fg3_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model grass fraction (case 3, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fgrass_case3";
  png, "Plots/"+timeslice+"_atm_grid_fgrass_case3", dpi=600;

  // CASE 3: bare-land fraction (atmosphere grid):
  fma;
  pli, fb3_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model bare land fraction (case 3, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fbare_case3";
  png, "Plots/"+timeslice+"_atm_grid_fbare_case3", dpi=600;
  
  // CASE 4: tree fraction (atmosphere grid):
  fma;
  pli, ft4_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model tree fraction (case 4, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_ftrees_case4";
  png, "Plots/"+timeslice+"_atm_grid_ftrees_case4", dpi=600;

  // CASE 4: grass fraction (atmosphere grid):
  fma;
  pli, fg4_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model grass fraction (case 4, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fgrass_case4";
  png, "Plots/"+timeslice+"_atm_grid_fgrass_case4", dpi=600;

  // CASE 4: bare-land fraction (atmosphere grid):
  fma;
  pli, fb4_a, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom_o, lat_o2, lon_o2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model bare land fraction (case 4, atmosphere grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_atm_grid_fbare_case4";
  png, "Plots/"+timeslice+"_atm_grid_fbare_case4", dpi=600;
  
  // CASE 2: tree fraction (original grid):
  fma;
  pli, ft2, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  plc, clim_t, lat_2, lon_2-180., levs=[.5], color="white", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model tree fraction (case 2, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_ftrees_case2";
  png, "Plots/"+timeslice+"_ini_grid_ftrees_case2", dpi=600;

  // CASE 2: grass fraction (original grid):
  fma;
  pli, fg2, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  plc, clim_g, lat_2, lon_2-180., levs=[.5], color="white", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model grass fraction (case 2, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_fgrass_case2";
  png, "Plots/"+timeslice+"_ini_grid_fgrass_case2", dpi=600;

  // CASE 2: bare-land fraction (original grid):
  fma;
  pli, fb2, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model bare land fraction (case 2, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_fbare_case2";
  png, "Plots/"+timeslice+"_ini_grid_fbare_case2", dpi=600;
  
  // CASE 3: tree fraction (original grid):
  fma;
  pli, ft3, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  plc, clim_t, lat_2, lon_2-180., levs=[.5], color="white", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model tree fraction (case 3, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_ftrees_case3";
  png, "Plots/"+timeslice+"_ini_grid_ftrees_case3", dpi=600;

  // CASE 3: grass fraction (original grid):
  fma;
  pli, fg3, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  plc, clim_g, lat_2, lon_2-180., levs=[.5], color="white", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model grass fraction (case 3, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_fgrass_case3";
  png, "Plots/"+timeslice+"_ini_grid_fgrass_case3", dpi=600;

  // CASE 3: bare-land fraction (original grid):
  fma;
  pli, fb3, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model bare land fraction (case 3, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_fbare_case3";
  png, "Plots/"+timeslice+"_ini_grid_fbare_case3", dpi=600;
  
  // CASE 4: tree fraction (original grid):
  fma;
  pli, ft4, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  plc, clim_t, lat_2, lon_2-180., levs=[.5], color="white", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model tree fraction (case 4, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_ftrees_case4";
  png, "Plots/"+timeslice+"_ini_grid_ftrees_case4", dpi=600;

  // CASE 4: grass fraction (original grid):
  fma;
  pli, fg4, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  plc, clim_g, lat_2, lon_2-180., levs=[.5], color="white", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model grass fraction (case 4, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_fgrass_case4";
  png, "Plots/"+timeslice+"_ini_grid_fgrass_case4", dpi=600;

  // CASE 4: bare-land fraction (original grid):
  fma;
  pli, fb4, -180, -90, 180, 90, cmin=0, cmax=1;
  plm, lat_ac2, lon_ac2-180., color=[50,50,50], width=1;
  plc, lom, lat_2, lon_2-180., levs=[.6],
    color="red", width=1;
  palette, "gray.gp";
  gridxy, base60=3;
  pltitle_height=14;
  pltitle, "Land model bare land fraction (case 4, original grid)";
  xytitles, "Longitude", "Latitude", [0.01,0.02];
  pdf, "Plots/"+timeslice+"_ini_grid_fbare_case4";
  png, "Plots/"+timeslice+"_ini_grid_fbare_case4", dpi=600;
  
  
}
